@@ -159,7 +159,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 			}
 			else
 			{
-				print_error(__func__, __FILE__, __LINE__, cpdd);
+				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
 				write_log_hash_check(cpinfo, ffrom, tto, sdir, cpdd, false);
 				unlink(cpinfo->to);
@@ -170,7 +170,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 		}
 		else
 		{
-			print_error(__func__, __FILE__, __LINE__, cpdd);
+			print_error("NODATA", __FILE__, __LINE__, cpdd);
 			fprintf(stderr, "コンペアに失敗しました\n");
 			fprintf(stderr, "%s\n", cpinfo->from);
 			fprintf(stderr, "%s\n", cpinfo->to);
@@ -179,7 +179,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 	}
 	else
 	{
-		print_error(__func__, __FILE__, __LINE__, cpdd);
+		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		fprintf(stderr, "コンペアに失敗しました\n");
 		fprintf(stderr, "%s\n", cpinfo->from);
 		fprintf(stderr, "%s\n", cpinfo->to);
