@@ -89,7 +89,7 @@ void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *
 	}
 	else if(froms.st_size != tos.st_size)
 	{
-		print_error(__func__, __FILE__, __LINE__, cpdd);
+		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		fprintf(stderr, "ファイルサイズが一致しませんでした、%sを削除します\n", cpinfo->to);
 		write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 		unlink(cpinfo->to);
@@ -168,7 +168,7 @@ void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *
 
 						MUNMAP_S
 
-						print_error(__func__, __FILE__, __LINE__, cpdd);
+						print_error("NODATA", __FILE__, __LINE__, cpdd);
 						fprintf(stderr, "ファイルが一致しませんでした、%sを削除します\n", cpinfo->to);
 						write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 						unlink(cpinfo->to);
