@@ -58,10 +58,10 @@ SDir * get_settings_dir(void)
 		sdir->log_dir = tmp; /* ~/.config/snowcp/log */
 
 		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "compare_error", NULL);
-		sdir->compare_error_dir = tmp; /* ~/.config/snowcp/log/compare_error */
+		sdir->hash_check_error_dir = tmp; /* ~/.config/snowcp/log/compare_error */
 
 		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "compare_success", NULL);
-		sdir->compare_success_dir = tmp; /* ~/.config/snowcp/log/compare_success */
+		sdir->hash_check_success_dir = tmp; /* ~/.config/snowcp/log/compare_success */
 	}
 
 	return sdir;
