@@ -5,22 +5,23 @@
 #include "xmalloc.h" // inline
 
 #include <string.h>
+#include <limits.h>
 
 #include <glib.h>
 #include <unistd.h>
 
 #define INPUT_LEN 256
-#define DEFAULT_BUFFER 64 * 1024 * 1024
+#define DEFAULT_BUFFER 32 * 1024 * 1024
 
-#define COMPARE_MODE_SET \
+#define HASH_CHECK_MODE_SET \
 {\
 	if(buf[2] == '1')\
 	{\
-		oparg->COMPARE_MODE = BEFORE;\
+		oparg->CHECK_MODE = BEFORE;\
 	}\
 	else if(buf[2] == '2')\
 	{\
-		oparg->COMPARE_MODE = AFTER;\
+		oparg->CHECK_MODE = AFTER;\
 	}\
 	else \
 	{\
@@ -39,7 +40,7 @@ OPArg * read_conf(const SDir *sdir)
 {
 	char buf[INPUT_LEN];
 	OPArg *oparg = xmalloc(sizeof(OPArg));
-	oparg->C = NOT;
+	oparg->CHECK = NOT;
 	oparg->I = NOT;
 	oparg->L = NOT;
 	oparg->M = NOT;
@@ -47,7 +48,7 @@ OPArg * read_conf(const SDir *sdir)
 	oparg->EFFECT = NOT;
 
 	oparg->buffer_size = DEFAULT_BUFFER;
-	oparg->COMPARE_MODE = NOT;
+	oparg->CHECK_MODE = NOT;
 	oparg->WRITE_MODE = SIZE_OR_TIME;
 	oparg->THREAD_MODE = DRIVE_AUTO;
 
@@ -95,13 +96,13 @@ OPArg * read_conf(const SDir *sdir)
 						break;
 					// SHA1SUM
 					case '1':
-						oparg->C = ONE;
-						COMPARE_MODE_SET
+						oparg->CHECK = ONE;
+						HASH_CHECK_MODE_SET
 						break;
 					// MD5SUM
 					case '5':
-						oparg->C = FIVE;
-						COMPARE_MODE_SET
+						oparg->CHECK = FIVE;
+						HASH_CHECK_MODE_SET
 						break;
 					// バッファサイズを指定
 					case 'b':
@@ -115,12 +116,19 @@ OPArg * read_conf(const SDir *sdir)
 							{
 								char *endptr = NULL;
 								off_t b = strtoll(cp, &endptr, 10);
+
+								if(b > INT_MAX)
+								{
+									fprintf(stderr, "バッファサイズの上限は2000MBです\n");
+									exit(EXIT_FAILURE);
+								}
+
 								// サイズをメガバイト単位にする
 								oparg->buffer_size = 1024 * 1024 * b;
 
-								if(oparg->buffer_size <= 0)
+								if(oparg->buffer_size <= 1)
 								{
-									fprintf(stderr, "バッファサイズが0以下です\n");
+									fprintf(stderr, "バッファサイズが1以下です\n");
 									exit(EXIT_FAILURE);
 								}
 							}
@@ -133,8 +141,8 @@ OPArg * read_conf(const SDir *sdir)
 						break;
 					// コンペア
 					case 'c':
-						oparg->C = MEMCMP;
-						COMPARE_MODE_SET
+						oparg->CHECK = MEMCMP;
+						HASH_CHECK_MODE_SET
 						break;
 					// 上書き時に確認する
 					case 'i':
@@ -149,6 +157,11 @@ OPArg * read_conf(const SDir *sdir)
 					case 'm':
 						oparg->M = MOVE;
 						break;
+					// ベリファイ（MD5）
+					case 'r':
+						oparg->CHECK = V_FIVE;
+						HASH_CHECK_MODE_SET
+						break;
 					// スレッドモード
 					case 't':
 						switch(buf[2])
