@@ -245,7 +245,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		}
 		else
 		{
-			print_error(__func__, __FILE__, __LINE__, cpdd);
+			print_error("NODATA", __FILE__, __LINE__, cpdd);
 			fprintf(stderr, "%s をコピーできません\n", cpinfo->from);
 		}
 	}
@@ -655,7 +655,7 @@ LOOP_END:
 
 	write_now = NULL;
 
-	if((from_open == true) && (to_open == true) && (total_read_local == total_write_local))
+	if((from_open == true) && (to_open == true) && (from_size_local == total_write_local))
 	{
 		cpinfo->write = true;
 	}
@@ -690,7 +690,7 @@ LOOP_END:
 			break;
 
 		case V_FIVE:
-			if((cpinfo->verify_md5 != NULL) && (cpinfo->write = true))
+			if((cpinfo->verify_md5 != NULL) && (to_open == true))
 			{
 				verify_hash(oparg, cpinfo, sdir, cpdd);
 			}
@@ -778,12 +778,13 @@ static void * read_thread(void *unknown)
 static void * write_thread(void *unknown)
 {
 	int i = wbuf_num;
-	char *tmp = (char *)buf[i];
-	const char * const endp = tmp + next_write_size[i];
 	unknown++;	// コンパイル時のwarningを出さないようにするため
 
 	if(next_write_size[i] > 0)
 	{
+		char *tmp = (char *)buf[i];
+		const char * const endp = tmp + next_write_size[i];
+
 		while(tmp < endp)
 		{
 			errno = 0;
