@@ -248,16 +248,16 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 		switch(cpinfo->from_type)
 		{
 		case REGULAR:
-			if(oparg->CHECK != NOT)
+			if(oparg->CHECK == NOT)
 			{
-				if(cpinfo->hash_check == true)
+				if((cpinfo->write == true) && (cpinfo->from_size == cpinfo->to_size))
 				{
 					FILE_REMOVE
 				}
 			}
 			else
 			{
-				if((cpinfo->write == true) && (cpinfo->from_size <= cpinfo->to_size))
+				if((cpinfo->hash_check == true) && (cpinfo->write == true) && (cpinfo->from_size == cpinfo->to_size))
 				{
 					FILE_REMOVE
 				}
