@@ -175,7 +175,7 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 			else
 			{
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
-				print_error(__func__, __FILE__, __LINE__, cpdd);
+				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);
 				cpinfo->write = false;
 				unlink(cpinfo->to);
@@ -185,7 +185,7 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 		{
 			fprintf(stderr, "ベリファイ出来ません\n");
 			fprintf(stderr, "メモリの確保に失敗しました\n");
-			print_error(__func__, __FILE__, __LINE__, cpdd);
+			print_error("NODATA", __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
 			cpinfo->write = false;
 		}
@@ -194,7 +194,7 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 	{
 		fprintf(stderr, "ベリファイに失敗しました\n");
 		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->to);
-		print_error(__func__, __FILE__, __LINE__, cpdd);
+		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
 		cpinfo->write = false;
 	}
